# Release team

The release team (RT) is an charge reviewing merge requests, and issuing new releases.

The members of the RT are defined in `docs/CODEOWNERS` in the `main` branch of the repository.

The RT itself adds or removes RT members.

It is the RT's duty to act on any merge request in a timely manner.

A code review of at least one RT member is required for any changeset to be merged into the `main` branch.

When all technical checks pass (e.g., CI success, resolved pull-request conversations), any RT member approval is a sufficient condition for an (automatic) merge of a changeset into the `main` branch.

RT members are not expected to be an expert in all techniques, features, and parts of the code base. Consequently, a team member should seek feedback prior to approving merge requests whenever necessary.
